@@ -87,7 +87,7 @@ def upload():
     if not FLAGS.container:
         print >>sys.stderr, "Missing --container flags" 
 
-    if not all(FLAGS.account, FLAGS.key, FLAGS.container):
+    if not all((FLAGS.account, FLAGS.key, FLAGS.container)):
         print __doc__
         sys.exit(1)
 
